@@ -32,7 +32,11 @@ open Vars
 open Globnames
 open CErrors
 
+#if COQVERSION >= 81900
+let generalize = Generalize.generalize
+#else
 let generalize = Tactics.generalize
+#endif
 
 open Ltac_plugin
 open EConstr
